@@ -1,9 +1,7 @@
 package NetPacket::ICMP;
-BEGIN {
-  $NetPacket::ICMP::AUTHORITY = 'cpan:YANICK';
-}
-# ABSTRACT: Assemble and disassemble ICMP (Internet Control Message Protocol) packets. 
-$NetPacket::ICMP::VERSION = '1.6.0';
+our $AUTHORITY = 'cpan:YANICK';
+# ABSTRACT: Assemble and disassemble ICMP (Internet Control Message Protocol) packets.
+$NetPacket::ICMP::VERSION = '1.7.0';
 use strict;
 use warnings;
 
@@ -32,7 +30,7 @@ our @EXPORT_OK = qw(icmp_strip icmp_infotype
 our %EXPORT_TAGS = (
     ALL         => [@EXPORT_OK],
     types       => [qw(ICMP_ECHOREPLY ICMP_UNREACH ICMP_SOURCEQUENCH
-                       ICMP_REDIRECT ICMP_ECHO ICMP_ROUTERADVERT 
+                       ICMP_REDIRECT ICMP_ECHO ICMP_ROUTERADVERT
                        ICMP_ROUTERSOLICIT ICMP_TIMXCEED ICMP_PARAMPROB
                        ICMP_TSTAMP ICMP_TSTAMPREPLY ICMP_IREQ ICMP_IREQREPLY
                        ICMP_MASKREQ ICMP_MASKREPLY)],
@@ -150,8 +148,9 @@ sub decode {
 # Strip a packet of its header and return the data
 #
 
-undef &icmp_strip;
-*icmpstrip = \&strip;
+sub icmpstrip {
+  goto \&strip;
+}
 
 sub strip {
     my ($pkt) = @_;
@@ -166,17 +165,16 @@ sub strip {
 
 sub encode {
     my $self = shift;
-    my ($ip) = @_;
     my ($packet);
-    
+
     # Checksum the packet
     $self->checksum();
 
     # Put the packet together
-    $packet = pack("CCna*", $self->{type}, $self->{code}, 
+    $packet = pack("CCna*", $self->{type}, $self->{code},
                 $self->{cksum}, $self->{data});
 
-    return($packet); 
+    return($packet);
 }
 
 #
@@ -184,7 +182,6 @@ sub encode {
 
 sub checksum {
     my $self = shift;
-    my ($ip) = @_;
     my ($packet,$zero);
 
     # Put the packet together for checksumming
@@ -208,11 +205,11 @@ sub checksum {
 
 =head1 NAME
 
-NetPacket::ICMP - Assemble and disassemble ICMP (Internet Control Message Protocol) packets. 
+NetPacket::ICMP - Assemble and disassemble ICMP (Internet Control Message Protocol) packets.
 
 =head1 VERSION
 
-version 1.6.0
+version 1.7.0
 
 =head1 SYNOPSIS
 
@@ -225,7 +222,7 @@ version 1.6.0
 =head1 DESCRIPTION
 
 C<NetPacket::ICMP> provides a set of routines for assembling and
-disassembling packets using ICMP (Internet Control Message Protocol). 
+disassembling packets using ICMP (Internet Control Message Protocol).
 
 =head2 Methods
 
@@ -240,7 +237,7 @@ is passed to this method.
 
 =item C<NetPacket::ICMP-E<gt>encode()>
 
-Return an ICMP packet encoded with the instance data specified. 
+Return an ICMP packet encoded with the instance data specified.
 
 =back
 
@@ -290,7 +287,7 @@ none
 
 =item exportable
 
-ICMP message types: 
+ICMP message types:
     ICMP_ECHOREPLY ICMP_UNREACH ICMP_SOURCEQUENCH
     ICMP_REDIRECT ICMP_ECHO ICMP_ROUTERADVERT
     ICMP_ROUTERSOLICIT ICMP_TIMXCEED ICMP_PARAMPROB
@@ -308,7 +305,7 @@ The following tags group together related exportable items.
   ICMP_ECHOREPLY ICMP_UNREACH ICMP_SOURCEQUENCH
   ICMP_REDIRECT ICMP_ECHO ICMP_ROUTERADVERT
   ICMP_ROUTERSOLICIT ICMP_TIMXCEED ICMP_PARAMPROB
-  ICMP_TSTAMP ICMP_TSTAMPREPLY ICMP_IREQ 
+  ICMP_TSTAMP ICMP_TSTAMPREPLY ICMP_IREQ
   ICMP_IREQREPLY ICMP_MASKREQ ICMP_MASKREPLY
 
 =item C<:strip>
@@ -325,7 +322,7 @@ All the above exportable items.
 
 =head1 EXAMPLE
 
-The following example prints the ICMP type, code, and checksum 
+The following example prints the ICMP type, code, and checksum
 fields.
 
   #!/usr/bin/perl -w
@@ -361,7 +358,7 @@ fields.
 
 Copyright (c) 2001 Tim Potter and Stephanie Wehner.
 
-Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
+Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of
 the participants in the CRC for Advanced Computational Systems
 ('ACSys').
 
