@@ -1,9 +1,7 @@
 package NetPacket::IPX;
-BEGIN {
-  $NetPacket::IPX::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Assemble and disassemble IPX packets
-$NetPacket::IPX::VERSION = '1.6.0';
+$NetPacket::IPX::VERSION = '1.7.0';
 use strict;
 use warnings;
 
@@ -139,7 +137,7 @@ NetPacket::IPX - Assemble and disassemble IPX packets
 
 =head1 VERSION
 
-version 1.6.0
+version 1.7.0
 
 =head1 SYNOPSIS
 
