@@ -1,9 +1,7 @@
 package NetPacket::USBMon;
-BEGIN {
-  $NetPacket::USBMon::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Assemble and disassemble USB packets captured via Linux USBMon interface.
-$NetPacket::USBMon::VERSION = '1.6.0';
+$NetPacket::USBMon::VERSION = '1.7.0';
 use 5.10.0;
 use strict;
 use warnings;
@@ -147,7 +145,7 @@ NetPacket::USBMon - Assemble and disassemble USB packets captured via Linux USBM
 
 =head1 VERSION
 
-version 1.6.0
+version 1.7.0
 
 =head1 SYNOPSIS
 
